from micropm4py import log, petrinet, util, conversion, visualization

__version__ = '0.0.8'
__doc__ = "MicroPM4Py - Process Mining for Micro-Controllers"
__author__ = 'Alessandro Berti'
__author_email__ = 'alessandro.berti89@gmail.com'
__maintainer__ = 'Alessandro Berti'
__maintainer_email__ = "alessandro.berti89@gmail.com"
